==> ducene-0.1.0.tar.gz: test/field_highlight_test.dart <==
// Copyright (c) 2016, Shinichiro Abe. All rights reserved. Use of this source code
// is governed by a BSD-style license that can be found in the LICENSE file.

import 'package:ducene/ducene.dart';
import 'package:test/test.dart';

void main() {

  group('A group of fieldHighlight', () {
    Analyzer ws;

    setUp(() {
      ws = new WhitespaceAnalyzer();
    });

    test('test getTerms()', () {
      BoolQuery q = new BoolQuery(Op.or)
      ..append("f1", "f1-1", analyzer: ws)
      ..append("f1", "f1-2", analyzer: ws)
      ..append("f2", "f2-1");
      expect(FieldHighlight.getTerms(q, "f1"), ["f1-1", "f1-2"]);
    });

    test('test getOffsets()', () {
      List<String> terms
      = ["keyword", 'bb', "wo", "word",
      "a keyword bb", "a keyword bb"
      " keyword ", " keyword", "cc"];
      String text = "AAA keyword BBB CCC";
      expect(FieldHighlight.getOffsets(terms, text), [{2: 14}, {16: 18}]);
    });

    test('test getOffsets()', () {
      List<String> terms
      = ["aaa bbb", "bbb ccc"];
      String text = "AAA BBB CCC";
      expect(FieldHighlight.getOffsets(terms, text), [{0: 7}]);
    });

    test('test markTags()', () {
      String text = "0123456789";
      var r = FieldHighlight.markTags([{1: 3}, {5: 7}], text, '<b>', '</b>');
      expect(r, '0<b>12</b>34<b>56</b>789');
    });

    test('test getSnippet()', () {
      BoolQuery q = new BoolQuery(Op.or)
          .append("f1", "keyword", analyzer: ws)
          .append("f1", "bbb", analyzer: ws);
      String text = "AAA keyword BBB";
      expect(FieldHighlight.getSnippet(q, 'f1', text),
          'AAA <b>keyword</b> <b>BBB</b>');
    });

    //####  sample tests ####//
    String field = 'dummy';
    String text = 'AAA Keyword BBB';

    test('test whitespace', () {
      BoolQuery q = new BoolQuery(Op.or).append(field, "Keyword", analyzer: ws);
      String r = FieldHighlight.getSnippet(q, field, text);
      expect(r, "AAA <b>Keyword</b> BBB");
    });

    test('test whitespace lower input', () {
      BoolQuery q = new BoolQuery(Op.or).append(field, "keyword", analyzer: ws);
      String r = FieldHighlight.getSnippet(q, field, text);
      expect(r, "AAA <b>Keyword</b> BBB");
    });

    Analyzer uniGram = new NGramAnalyzer(1);

    test('test uniGram', () {
      BoolQuery q = new BoolQuery(Op.or).append(field, "K", analyzer: uniGram);
      String r = FieldHighlight.getSnippet(q, field, text);
      expect(r, "AAA <b>K</b>eyword BBB");
    });

    Analyzer hl = new UniGramAnalyzer();

    test('test hl', () {
      BoolQuery q = new BoolQuery(Op.or).append(field, "K", analyzer: hl);
      String r = FieldHighlight.getSnippet(q, field, text);
      expect(r, "AAA <b>K</b>eyword BBB");
    });

    test('test uniGram lower input', () {
      BoolQuery q = new BoolQuery(Op.or).append(field, "k", analyzer: uniGram);
      String r = FieldHighlight.getSnippet(q, field, text);
      expect(r, "AAA <b>K</b>eyword BBB");
    });

    test('test hl lower input', () {
      BoolQuery q = new BoolQuery(Op.or).append(field, "k", analyzer: hl);
      String r = FieldHighlight.getSnippet(q, field, text);
      expect(r, "AAA <b>K</b>eyword BBB");
    });

    test('test uniGram 2 char', () {
      BoolQuery q = new BoolQuery(Op.or).append(field, "Ke", analyzer: uniGram);
      String r = FieldHighlight.getSnippet(q, field, text);
      expect(r, "AAA <b>K</b><b>e</b>yword BBB");
    });

    test('test hl 2 char', () {
      BoolQuery q = new BoolQuery(Op.or).append(field, "Ke", analyzer: hl);
      String r = FieldHighlight.getSnippet(q, field, text);
      expect(r, "AAA <b>K</b><b>e</b>yword BBB");
    });

  });

}

==> ducene-0.2.0.tar.gz: test/field_highlight_test.dart <==
// Copyright (c) 2016, Shinichiro Abe. All rights reserved. Use of this source code
// is governed by a BSD-style license that can be found in the LICENSE file.

import 'package:ducene/analysis.dart';
import 'package:ducene/search.dart';
import 'package:test/test.dart';

void main() {

  group('A group of fieldHighlight', () {
    Analyzer ws;

    setUp(() {
      ws = new WhitespaceAnalyzer();
    });

    test('test getTerms()', () {
      BoolQuery q = new BoolQuery()
      ..append("f1", "f1-1", analyzer: ws)
      ..append("f1", "f1-2", analyzer: ws)
      ..append("f2", "f2-1");
      expect(FieldHighlight.getTerms(q, "f1"), ["f1-1", "f1-2"]);
    });

    test('test getOffsets()', () {
      List<String> terms
      = ["keyword", 'bb', "wo", "word",
      "a keyword bb", "a keyword bb"
      " keyword ", " keyword", "cc"];
      String text = "AAA keyword BBB CCC";
      expect(FieldHighlight.getOffsets(terms, text), [{2: 14}, {16: 18}]);
    });

    test('test getOffsets()', () {
      List<String> terms
      = ["aaa bbb", "bbb ccc"];
      String text = "AAA BBB CCC";
      expect(FieldHighlight.getOffsets(terms, text), [{0: 7}]);
    });

    test('test markTags()', () {
      String text = "0123456789";
      var r = FieldHighlight.markTags([{1: 3}, {5: 7}], text, '<b>', '</b>');
      expect(r, '0<b>12</b>34<b>56</b>789');
    });

    test('test getSnippet()', () {
      BoolQuery q = new BoolQuery()
          .append("f1", "keyword", analyzer: ws)
          .append("f1", "bbb", analyzer: ws);
      String text = "AAA keyword BBB";
      expect(FieldHighlight.getSnippet(q, 'f1', text),
          'AAA <b>keyword</b> <b>BBB</b>');
    });

    //####  sample tests ####//
    String field = 'dummy';
    String text = 'AAA Keyword BBB';

    test('test whitespace', () {
      BoolQuery q = new BoolQuery().append(field, "Keyword", analyzer: ws);
      String r = FieldHighlight.getSnippet(q, field, text);
      expect(r, "AAA <b>Keyword</b> BBB");
    });

    test('test whitespace lower input', () {
      BoolQuery q = new BoolQuery().append(field, "keyword", analyzer: ws);
      String r = FieldHighlight.getSnippet(q, field, text);
      expect(r, "AAA <b>Keyword</b> BBB");
    });

    Analyzer uniGram = new NGramAnalyzer(1);

    test('test uniGram', () {
      BoolQuery q = new BoolQuery().append(field, "K", analyzer: uniGram);
      String r = FieldHighlight.getSnippet(q, field, text);
      expect(r, "AAA <b>K</b>eyword BBB");
    });

    Analyzer hl = new UniGramAnalyzer();

    test('test hl', () {
      BoolQuery q = new BoolQuery().append(field, "K", analyzer: hl);
      String r = FieldHighlight.getSnippet(q, field, text);
      expect(r, "AAA <b>K</b>eyword BBB");
    });

    test('test uniGram lower input', () {
      BoolQuery q = new BoolQuery().append(field, "k", analyzer: uniGram);
      String r = FieldHighlight.getSnippet(q, field, text);
      expect(r, "AAA <b>K</b>eyword BBB");
    });

    test('test hl lower input', () {
      BoolQuery q = new BoolQuery().append(field, "k", analyzer: hl);
      String r = FieldHighlight.getSnippet(q, field, text);
      expect(r, "AAA <b>K</b>eyword BBB");
    });

    test('test uniGram 2 char', () {
      BoolQuery q = new BoolQuery().append(field, "Ke", analyzer: uniGram);
      String r = FieldHighlight.getSnippet(q, field, text);
      expect(r, "AAA <b>K</b><b>e</b>yword BBB");
    });

    test('test hl 2 char', () {
      BoolQuery q = new BoolQuery().append(field, "Ke", analyzer: hl);
      String r = FieldHighlight.getSnippet(q, field, text);
      expect(r, "AAA <b>K</b><b>e</b>yword BBB");
    });

  });

}
